@@ -11,22 +11,21 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from pytorch_lightning.utilities import FAIRSCALE_AVAILABLE
+from pytorch_lightning.core.lightning import LightningModule
+from pytorch_lightning.overrides.base import _LightningModuleWrapperBase, unwrap_lightning_module
+from pytorch_lightning.utilities import _FAIRSCALE_AVAILABLE
 
 LightningShardedDataParallel = None
-if FAIRSCALE_AVAILABLE:
+if _FAIRSCALE_AVAILABLE:
     from fairscale.nn.data_parallel.sharded_ddp import ShardedDataParallel
 
-    class LightningShardedDataParallel(ShardedDataParallel):
+    class LightningShardedDataParallel(_LightningModuleWrapperBase):
+        # Just do this for later docstrings
+        pass
 
-        def forward(self, *inputs, **kwargs):
-            if self.enable_broadcast_buffers:
-                self.sync_buffers()
+    def unwrap_lightning_module_sharded(wrapped_model) -> LightningModule:
+        model = wrapped_model
+        if isinstance(model, ShardedDataParallel):
+            model = model.module
 
-            if self.module.training:
-                outputs = self.module.training_step(*inputs, **kwargs)
-            elif self.module.testing:
-                outputs = self.module.test_step(*inputs, **kwargs)
-            else:
-                outputs = self.module.validation_step(*inputs, **kwargs)
-            return outputs
+        return unwrap_lightning_module(model)
