@@ -15,7 +15,7 @@
 from typing import Union
 
 from pytorch_lightning.loggers.base import DummyLogger
-from pytorch_lightning.utilities import rank_zero_info, rank_zero_warn
+from pytorch_lightning.utilities import rank_zero_info
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 
 
@@ -25,13 +25,14 @@ class DebuggingConnector:
         self.trainer = trainer
 
     def on_init_start(
-            self,
-            limit_train_batches,
-            limit_val_batches,
-            limit_test_batches,
-            val_check_interval,
-            overfit_batches,
-            fast_dev_run
+        self,
+        limit_train_batches,
+        limit_val_batches,
+        limit_test_batches,
+        limit_predict_batches,
+        val_check_interval,
+        overfit_batches,
+        fast_dev_run,
     ):
         if not isinstance(fast_dev_run, (bool, int)):
             raise MisconfigurationException(
@@ -56,6 +57,7 @@ class DebuggingConnector:
             limit_train_batches = fast_dev_run
             limit_val_batches = fast_dev_run
             limit_test_batches = fast_dev_run
+            limit_predict_batches = fast_dev_run
             self.trainer.max_steps = fast_dev_run
             self.trainer.num_sanity_val_steps = 0
             self.trainer.max_epochs = 1
@@ -71,6 +73,7 @@ class DebuggingConnector:
         self.trainer.limit_train_batches = _determine_batch_limits(limit_train_batches, 'limit_train_batches')
         self.trainer.limit_val_batches = _determine_batch_limits(limit_val_batches, 'limit_val_batches')
         self.trainer.limit_test_batches = _determine_batch_limits(limit_test_batches, 'limit_test_batches')
+        self.trainer.limit_predict_batches = _determine_batch_limits(limit_predict_batches, 'limit_predict_batches')
         self.trainer.val_check_interval = _determine_batch_limits(val_check_interval, 'val_check_interval')
         self.trainer.overfit_batches = _determine_batch_limits(overfit_batches, 'overfit_batches')
         self.determine_data_use_amount(self.trainer.overfit_batches)
