@@ -12,23 +12,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from enum import Enum
 from functools import wraps
 from typing import Callable, Optional
 
 import pytorch_lightning
+from pytorch_lightning.utilities import LightningEnum
 
 
-class TrainerState(str, Enum):
+class TrainerState(LightningEnum):
     """ State which is set in the :class:`~pytorch_lightning.trainer.trainer.Trainer`
     to indicate what is currently or was executed.
 
-    >>> # you can math the type with string
+    >>> # you can compare the type with a string
     >>> TrainerState.RUNNING == 'RUNNING'
     True
-    >>> # which is case sensitive
+    >>> # which is case insensitive
     >>> TrainerState.FINISHED == 'finished'
-    False
+    True
     """
     INITIALIZING = 'INITIALIZING'
     RUNNING = 'RUNNING'
@@ -36,6 +36,20 @@ class TrainerState(str, Enum):
     INTERRUPTED = 'INTERRUPTED'
 
 
+class RunningStage(LightningEnum):
+    """Type of train phase.
+
+    >>> # you can match the Enum with string
+    >>> RunningStage.TRAINING == 'train'
+    True
+    """
+    TRAINING = 'train'
+    EVALUATING = 'eval'
+    TESTING = 'test'
+    PREDICTING = 'predict'
+    TUNING = 'tune'
+
+
 def trainer_state(*, entering: Optional[TrainerState] = None, exiting: Optional[TrainerState] = None) -> Callable:
     """ Decorator for :class:`~pytorch_lightning.trainer.trainer.Trainer` methods
     which changes state to `entering` before the function execution and `exiting`
@@ -45,6 +59,7 @@ def trainer_state(*, entering: Optional[TrainerState] = None, exiting: Optional[
     """
 
     def wrapper(fn) -> Callable:
+
         @wraps(fn)
         def wrapped_fn(self, *args, **kwargs):
             if not isinstance(self, pytorch_lightning.Trainer):
