@@ -12,8 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from distutils.version import LooseVersion
-import torch
+from typing import Union
+
 from torch.utils.data import DataLoader, IterableDataset
 
 from pytorch_lightning.utilities import rank_zero_warn
@@ -30,18 +30,26 @@ def has_len(dataloader: DataLoader) -> bool:
     try:
         # try getting the length
         if len(dataloader) == 0:
-            raise ValueError('`Dataloader` returned 0 length.'
-                             ' Please make sure that your Dataloader at least returns 1 batch')
+            raise ValueError('`Dataloader` returned 0 length. Please make sure that it returns at least 1 batch')
         has_len = True
     except TypeError:
         has_len = False
     except NotImplementedError:  # e.g. raised by torchtext if a batch_size_fn is used
         has_len = False
 
-    if has_len and has_iterable_dataset(dataloader) and LooseVersion(torch.__version__) >= LooseVersion("1.4.0"):
+    if has_len and has_iterable_dataset(dataloader):
         rank_zero_warn(
             'Your `IterableDataset` has `__len__` defined.'
             ' In combination with multi-processing data loading (e.g. batch size > 1),'
             ' this can lead to unintended side effects since the samples will be duplicated.'
         )
     return has_len
+
+
+def get_len(dataloader: DataLoader) -> Union[int, float]:
+    """ Return the length of the given DataLoader. If ``__len__`` method is not implemented, return float('inf'). """
+
+    if has_len(dataloader):
+        return len(dataloader)
+
+    return float('inf')
